@@ -1,8 +1,8 @@
 from ._fitting import fitting
-
 import numpy as NUM
-from casacore import six
+import six
 from casacore.functionals import *
+from six import string_types
 
 
 class fitserver(object):
@@ -69,7 +69,7 @@ class fitserver(object):
             self._fitids.append({})
         else:
             # shouldn't happen
-            raise RangeError("fit id out of range")
+            raise IndexError("fit id out of range")
         self.init(n=n, ftype=ftype, colfac=colfac, lmfac=lmfac, fid=fid)
         return fid
 
@@ -100,13 +100,13 @@ class fitserver(object):
             return False
 
     def _gettype(self, ftype):
-        if isinstance(ftype, str):
+        if isinstance(ftype, string_types):
             ftype = ftype.lower()
             if ftype not in self._typeids:
                 raise TypeError("Illegal fitting type")
             else:
                 return self._typeids[ftype]
-        elif isinstance(ftype, int):
+        elif isinstance(ftype, six.integer_types):
             if ftype not in self._typeids.values():
                 raise TypeError("Illegal fitting type")
         else:
